# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import detection_instance_api_pb2 as fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2


class DetectionInstanceApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CacheDetectionInstancesDataByImageIdRequest = channel.unary_unary(
                '/DetectionInstanceApi/CacheDetectionInstancesDataByImageIdRequest',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequestRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequestResponse.FromString,
                )
        self.DeleteDetectionInstanceById = channel.unary_unary(
                '/DetectionInstanceApi/DeleteDetectionInstanceById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.FromString,
                )
        self.FindOrCreateHumanDetectionInstance = channel.unary_unary(
                '/DetectionInstanceApi/FindOrCreateHumanDetectionInstance',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateHumanDetectionInstanceRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateHumanDetectionInstanceResponse.FromString,
                )
        self.FindOrCreateMachineDetectionInstance = channel.unary_unary(
                '/DetectionInstanceApi/FindOrCreateMachineDetectionInstance',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateMachineDetectionInstanceRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateMachineDetectionInstanceResponse.FromString,
                )
        self.GetDetectionInstanceDataById = channel.unary_stream(
                '/DetectionInstanceApi/GetDetectionInstanceDataById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdResponse.FromString,
                )
        self.GetDetectionInstancesByImageId = channel.unary_unary(
                '/DetectionInstanceApi/GetDetectionInstancesByImageId',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdResponse.FromString,
                )
        self.TransitionDetectionInstanceState = channel.unary_unary(
                '/DetectionInstanceApi/TransitionDetectionInstanceState',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateResponse.FromString,
                )
        self.UpdateDetectionInstanceGeoBbox = channel.unary_unary(
                '/DetectionInstanceApi/UpdateDetectionInstanceGeoBbox',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxResponse.FromString,
                )
        self.GetDetectionInstanceBboxById = channel.unary_unary(
                '/DetectionInstanceApi/GetDetectionInstanceBboxById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdResponse.FromString,
                )
        self.UpdateDetectionInstanceGeoPoints = channel.unary_unary(
                '/DetectionInstanceApi/UpdateDetectionInstanceGeoPoints',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsResponse.FromString,
                )


class DetectionInstanceApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CacheDetectionInstancesDataByImageIdRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDetectionInstanceById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindOrCreateHumanDetectionInstance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindOrCreateMachineDetectionInstance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstanceDataById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstancesByImageId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TransitionDetectionInstanceState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDetectionInstanceGeoBbox(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstanceBboxById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDetectionInstanceGeoPoints(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DetectionInstanceApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CacheDetectionInstancesDataByImageIdRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CacheDetectionInstancesDataByImageIdRequest,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequestRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequestResponse.SerializeToString,
            ),
            'DeleteDetectionInstanceById': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDetectionInstanceById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.SerializeToString,
            ),
            'FindOrCreateHumanDetectionInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateHumanDetectionInstance,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateHumanDetectionInstanceRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateHumanDetectionInstanceResponse.SerializeToString,
            ),
            'FindOrCreateMachineDetectionInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateMachineDetectionInstance,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateMachineDetectionInstanceRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateMachineDetectionInstanceResponse.SerializeToString,
            ),
            'GetDetectionInstanceDataById': grpc.unary_stream_rpc_method_handler(
                    servicer.GetDetectionInstanceDataById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdResponse.SerializeToString,
            ),
            'GetDetectionInstancesByImageId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetectionInstancesByImageId,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdResponse.SerializeToString,
            ),
            'TransitionDetectionInstanceState': grpc.unary_unary_rpc_method_handler(
                    servicer.TransitionDetectionInstanceState,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateResponse.SerializeToString,
            ),
            'UpdateDetectionInstanceGeoBbox': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDetectionInstanceGeoBbox,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxResponse.SerializeToString,
            ),
            'GetDetectionInstanceBboxById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetectionInstanceBboxById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdResponse.SerializeToString,
            ),
            'UpdateDetectionInstanceGeoPoints': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDetectionInstanceGeoPoints,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'DetectionInstanceApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DetectionInstanceApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CacheDetectionInstancesDataByImageIdRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/CacheDetectionInstancesDataByImageIdRequest',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequestRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDetectionInstanceById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/DeleteDetectionInstanceById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindOrCreateHumanDetectionInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/FindOrCreateHumanDetectionInstance',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateHumanDetectionInstanceRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateHumanDetectionInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindOrCreateMachineDetectionInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/FindOrCreateMachineDetectionInstance',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateMachineDetectionInstanceRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateMachineDetectionInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstanceDataById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/DetectionInstanceApi/GetDetectionInstanceDataById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstancesByImageId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/GetDetectionInstancesByImageId',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TransitionDetectionInstanceState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/TransitionDetectionInstanceState',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDetectionInstanceGeoBbox(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/UpdateDetectionInstanceGeoBbox',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstanceBboxById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/GetDetectionInstanceBboxById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDetectionInstanceGeoPoints(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/UpdateDetectionInstanceGeoPoints',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
